@@ -1,5 +1,7 @@
 """
-Main interface for redshift-data service literal definitions.
+Type annotations for redshift-data service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/literals.html)
 
 Usage::
 
